package impl_es

import (
	"testing"
	"time"
)

func TestLog(t *testing.T) {
	urls := []string{"http://10.1.0.71:9101/"}
	log, err := NewLogger(urls, "", "", "es_log_test", "les_log_test", nil)
	if err != nil {
		t.Error("esLog 创建失败")
	}

	for i := 1; i <= 1000; i++ {
		log.DebugLog("Debug test %v", i)
		log.InfoLog("Info test %v", i)
		log.WarnLog("Warn test %v", i)
		log.ErrorLog("Error test %v", i)
		log.FatalLog("Fatal test %v", i)
		time.Sleep(time.Millisecond * 100)
	}

	time.Sleep(time.Second * 5)
}
